@@ -81,6 +81,6 @@ kappa_val_croisee <- function(don_S, don_T, njeu, n_obs, n_node = 6, adjust_S =
   }
   kapa[,1] <- kapa[,1]*adjust_S
   kapa[,2] <- kapa[,2]*adjust_T
-  utils::write.table(kapa, "kappa_valid_crois.txt", sep=" ", row.names = F, col.names = F)
+  #utils::write.table(kapa, "kappa_valid_crois.txt", sep=" ", row.names = F, col.names = F)
   return(kapa)
 }
