@@ -506,13 +506,14 @@
     double precision,dimension((m*(m+3)/2)),intent(out)::v
     double precision,dimension(:),allocatable::fcith ! scl_22-09-2017
     integer ::i0,m1,ll,i,k,j,iun,tail
-    double precision::fctnames,thn,th,z,vl,th2,vaux
-    external::fctnames
+    double precision::thn,th,z,vl,th2,vaux
+    double precision,external::fctnames
     !call intpr("derivaJ_scl 532", -1, m, 1)
     allocate(fcith(m)) ! scl_22-09-2017
     fcith = 0.d0
     !!print*,"suis dans derivaJ_scl, model=",model
     !stop
+    th=0.0d0
     select case(model)
     case(1)
         th=1.d-3 !joint
