@@ -414,7 +414,10 @@
     double precision,dimension(2)::su,sut1,sut0,sudc
     double precision::lam,lamdc,temp, tempscl
     double precision,parameter::pi=3.141592653589793d0
-    
+    su = 0.0d0 
+    sut1 = 0.d0 
+    sut0 = 0.d0 
+    sudc = 0.0d0 
     n = 0
     betaR = 0.d0
     etaR = 0.d0
@@ -622,7 +625,10 @@
     double precision,dimension(2)::su,sut1,sut0,sudc
     double precision::lam,lamdc,temp, tempscl
     double precision,parameter::pi=3.141592653589793d0
-
+    su  = 0.0d0 
+    sut1 = 0.0d0 
+    sut0 = 0.0d0 
+    sudc = 0.0d0 
     n = 0
     betaR = 0.d0
     etaR = 0.d0
