@@ -29,8 +29,8 @@ double precision function funcpajcompetingsplines(b,np,id,thi,jd,thj,k0)
     integer::n,i,j,k,l,vj,ig,choix
     integer,dimension(ngmax)::cpt!,cptmeta
     !cpt, cptmax = number of recurrent events for each person
-    double precision::pe1,pe2,pe3,pe4,inv,inv2,som1,som2,som3,som4,&
-    res,vet,vet2,vet3,vet4,h1,pi,frail,frail2,weight,weight2,ss
+    double precision::pe1,pe2,pe4,inv,inv2,som1,som2,som4,&
+    res,vet,vet2,vet4,h1,pi,frail,frail2,weight,weight2,ss
     ! vet = temporary value for relative hazard for an individual
     ! h1 = distance between knot points
     ! frail = used in GH quadrature for integration
@@ -57,7 +57,6 @@ double precision function funcpajcompetingsplines(b,np,id,thi,jd,thj,k0)
     !double precision,dimension(0:ndatemeta)::ut3
     double precision,dimension(0:ndatemaxdc)::ut4
     !cumulative hazards at each event time on the grid of event times
-    double precision::int
     choix=0
     ig=0
     vj=0
