@@ -8,7 +8,7 @@
     t0,t1,t0dc,t1dc,c,cdc,nsujet, &
     nst,effet,ng,g,nig,kkapa,indic_alpha,alpha,theta, &
     auxig,aux1,aux2,res1,res3,typeof,pe,resnonpen,nb_gl, &
-	famillerisque, ni_cur
+    famillerisque!, ni_cur
     use residusM
     use betatttps
 
@@ -26,13 +26,13 @@
     double precision,dimension(2)::k0
     double precision::result,result3,abserr,resabs,resasc,resultdc
     double precision,external::risqindivrecPH,risqindivdcPH
-	double precision,external::risqindivrecAH_initial,risqindivrecAH_positif
-	double precision,external::risqindivdcAH_initial,risqindivdcAH_positif
-	double precision,external::risqindivrecAH_alternatif,risqindivdcAH_alternatif
-	integer::famillerisquedc,famillerisquerec
+    double precision,external::risqindivrecAH_initial,risqindivrecAH_positif
+    double precision,external::risqindivdcAH_initial,risqindivdcAH_positif
+    double precision,external::risqindivrecAH_alternatif,risqindivdcAH_alternatif
+    integer::famillerisquedc,famillerisquerec
 
     famillerisquedc  = famillerisque(1)
-	famillerisquerec = famillerisque(2)
+    famillerisquerec = famillerisque(2)
     kkapa=k0
 
     bh=b
@@ -84,13 +84,13 @@
 ! Fonction de risque de base recidive au temps T_ij
 !cccccccccccccccccccccc
         if (c(i).eq.1) then
-		    if(famillerisquerec .eq. 0) then
+            if(famillerisquerec .eq. 0) then
                 res2(g(i)) = res2(g(i)) + dlog(risqindivrecPH(t1(i),i,bh,np))
-			else if (famillerisquerec .eq. 3) then
-			    res2(g(i)) = res2(g(i)) + dlog(risqindivrecAH_positif(t1(i),i,bh,np))
-			else if (famillerisquerec .eq. 4) then
-			    res2(g(i)) = res2(g(i)) + dlog(risqindivrecAH_alternatif(t1(i),i,bh,np))
-			endif
+            else if (famillerisquerec .eq. 3) then
+                res2(g(i)) = res2(g(i)) + dlog(risqindivrecAH_positif(t1(i),i,bh,np))
+            else if (famillerisquerec .eq. 4) then
+                res2(g(i)) = res2(g(i)) + dlog(risqindivrecAH_alternatif(t1(i),i,bh,np))
+            endif
         endif
 
         if ((res2(g(i)).ne.res2(g(i))).or.(abs(res2(g(i))).ge. 1.d30)) then
@@ -105,13 +105,13 @@
         if(famillerisquerec .eq. 0) then
             call integration(risqindivrecPH,0.d0,t1(i),result,abserr,resabs,resasc,i,bh,np)
             res1(g(i)) = res1(g(i)) + result
-		else if (famillerisquerec .eq. 3) then
-		    call integration(risqindivrecAH_positif,0.d0,t1(i),result,abserr,resabs,resasc,i,bh,np)
+        else if (famillerisquerec .eq. 3) then
+            call integration(risqindivrecAH_positif,0.d0,t1(i),result,abserr,resabs,resasc,i,bh,np)
             res1(g(i)) = res1(g(i)) + result
-		else if (famillerisquerec .eq. 4) then
-		    call integration(risqindivrecAH_alternatif,0.d0,t1(i),result,abserr,resabs,resasc,i,bh,np)
+        else if (famillerisquerec .eq. 4) then
+            call integration(risqindivrecAH_alternatif,0.d0,t1(i),result,abserr,resabs,resasc,i,bh,np)
             res1(g(i)) = res1(g(i)) + result
-		endif
+        endif
 
         if ((res1(g(i)).ne.res1(g(i))).or.(abs(res1(g(i))).ge. 1.d30)) then
             !print*,"here2"
@@ -125,13 +125,13 @@
         if(famillerisquerec .eq. 0) then
             call integration(risqindivrecPH,0.d0,t0(i),result3,abserr,resabs,resasc,i,bh,np)
             res3(g(i)) = res3(g(i)) + result3
-		else if (famillerisquerec .eq. 3) then
-		    call integration(risqindivrecAH_positif,0.d0,t0(i),result3,abserr,resabs,resasc,i,bh,np)
+        else if (famillerisquerec .eq. 3) then
+            call integration(risqindivrecAH_positif,0.d0,t0(i),result3,abserr,resabs,resasc,i,bh,np)
             res3(g(i)) = res3(g(i)) + result3
-		else if (famillerisquerec .eq. 4) then
-		    call integration(risqindivrecAH_alternatif,0.d0,t0(i),result3,abserr,resabs,resasc,i,bh,np)
+        else if (famillerisquerec .eq. 4) then
+            call integration(risqindivrecAH_alternatif,0.d0,t0(i),result3,abserr,resabs,resasc,i,bh,np)
             res3(g(i)) = res3(g(i)) + result3
-		endif
+        endif
 
         if ((res3(g(i)).ne.res3(g(i))).or.(abs(res3(g(i))).ge. 1.d30)) then
             !print*,"here3"
@@ -150,13 +150,13 @@
 ! Fonction de risque de deces au temps T_i*
 !cccccccccccccccccc
         if (cdc(k).eq.1) then
-		    if(famillerisquedc .eq. 0) then
+            if(famillerisquedc .eq. 0) then
                 res2dc(k) = dlog(risqindivdcPH(t1dc(k),k,bh,np))
-			else if (famillerisquedc .eq. 3) then
-			    res2dc(k) = dlog(risqindivdcAH_positif(t1dc(k),k,bh,np))
-			else if (famillerisquedc .eq. 4) then
-			    res2dc(k) = dlog(risqindivdcAH_alternatif(t1dc(k),k,bh,np))
-			endif
+            else if (famillerisquedc .eq. 3) then
+                res2dc(k) = dlog(risqindivdcAH_positif(t1dc(k),k,bh,np))
+            else if (famillerisquedc .eq. 4) then
+                res2dc(k) = dlog(risqindivdcAH_alternatif(t1dc(k),k,bh,np))
+            endif
         endif
 
         if ((res2dc(k).ne.res2dc(k)).or.(abs(res2dc(k)).ge. 1.d30)) then
@@ -171,13 +171,13 @@
         if(famillerisquedc .eq. 0) then
             call integration(risqindivdcPH,t0dc(k),t1dc(k),resultdc,abserr,resabs,resasc,k,bh,np)
             aux1(k) = resultdc
-		else if (famillerisquedc .eq. 3) then
-		    call integration(risqindivdcAH_positif,t0dc(k),t1dc(k),resultdc,abserr,resabs,resasc,k,bh,np)
+        else if (famillerisquedc .eq. 3) then
+            call integration(risqindivdcAH_positif,t0dc(k),t1dc(k),resultdc,abserr,resabs,resasc,k,bh,np)
             aux1(k) = resultdc
-		else if (famillerisquedc .eq. 4) then
-		    call integration(risqindivdcAH_alternatif,t0dc(k),t1dc(k),resultdc,abserr,resabs,resasc,k,bh,np)
+        else if (famillerisquedc .eq. 4) then
+            call integration(risqindivdcAH_alternatif,t0dc(k),t1dc(k),resultdc,abserr,resabs,resasc,k,bh,np)
             aux1(k) = resultdc
-		endif
+        endif
 
         if ((aux1(k).ne.aux1(k)).or.(abs(aux1(k)).ge. 1.d30)) then
             !print*,"here5"
@@ -680,9 +680,9 @@
     end select
 
     risqindivrecAH_positif = bbb+dlog(vet)
-	if (risqindivrecAH_positif.le.0.d0) then
-	    risqindivrecAH_positif = 1d-16
-	endif
+    if (risqindivrecAH_positif.le.0.d0) then
+        risqindivrecAH_positif = 1d-16
+    endif
 
     return
 
@@ -885,9 +885,9 @@
     end select
 
     risqindivdcAH_positif = bbb+dlog(vet2)
-	if (risqindivdcAH_positif.le.0.d0) then
-	    risqindivdcAH_positif = 1d-16
-	endif
+    if (risqindivdcAH_positif.le.0.d0) then
+        risqindivdcAH_positif = 1d-16
+    endif
 
     return
 
