@@ -619,6 +619,44 @@ double precision function funcpajlongisplines2(b,np,id,thi,jd,thj,k0)
             *the2(i)*m1m(i))
           endif
       end do
+
+
+
+
+
+      do i=1,n-3
+        if(effet.eq.1) then
+          !trivariate model, need penalization for both terminal and recurrent times
+          pe1 = pe1+(the1(i-3)*the1(i-3)*m3m3(i))+(the1(i-2) &
+          *the1(i-2)*m2m2(i))+(the1(i-1)*the1(i-1)*m1m1(i))+( &
+          the1(i)*the1(i)*mmm(i))+(2.d0*the1(i-3)*the1(i-2)* &
+          m3m2(i))+(2.d0*the1(i-3)*the1(i-1)*m3m1(i))+(2.d0* &
+          the1(i-3)*the1(i)*m3m(i))+(2.d0*the1(i-2)*the1(i-1)* &
+          m2m1(i))+(2.d0*the1(i-2)*the1(i)*m2m(i))+(2.d0*the1(i-1) &
+          *the1(i)*m1m(i))
+
+          pe2 = pe2+(the2(i-3)*the2(i-3)*m3m3(i))+(the2(i-2) &
+          *the2(i-2)*m2m2(i))+(the2(i-1)*the2(i-1)*m1m1(i))+( &
+          the2(i)*the2(i)*mmm(i))+(2.d0*the2(i-3)*the2(i-2)* &
+          m3m2(i))+(2.d0*the2(i-3)*the2(i-1)*m3m1(i))+(2.d0* &
+          the2(i-3)*the2(i)*m3m(i))+(2.d0*the2(i-2)*the2(i-1)* &
+          m2m1(i))+(2.d0*the2(i-2)*the2(i)*m2m(i))+(2.d0*the2(i-1) &
+          *the2(i)*m1m(i))
+        else
+          !joint model for longitudinal outcome with 1 single terminal time
+          !The baseline hazard function is stored in the vector the2
+          pe1 = 0.d0
+          pe2 = pe2+(the2(i-3)*the2(i-3)*m3m3(i))+(the2(i-2) &
+          *the2(i-2)*m2m2(i))+(the2(i-1)*the2(i-1)*m1m1(i))+( &
+          the2(i)*the2(i)*mmm(i))+(2.d0*the2(i-3)*the2(i-2)* &
+          m3m2(i))+(2.d0*the2(i-3)*the2(i-1)*m3m1(i))+(2.d0* &
+          the2(i-3)*the2(i)*m3m(i))+(2.d0*the2(i-2)*the2(i-1)* &
+          m2m1(i))+(2.d0*the2(i-2)*the2(i)*m2m(i))+(2.d0*the2(i-1) &
+          *the2(i)*m1m(i))
+        end if
+      end do
+
+
       pe = k0(1)*pe1 + k0(2)*pe2
       resnonpen = res
       res = res - pe
